# -*- coding: utf-8 -*-

from __future__ import division

from django.conf import settings
from django.db import transaction
from django_logit import logit
from django_response import response

from mch.models import ConsumeInfoSubmitLogInfo
from statistic.models import ConsumeModelSaleStatisticInfo
from utils.error.errno_utils import ProductBrandStatusCode, ProductMachineStatusCode


WECHAT = settings.WECHAT


@logit
def querysn(request):
    brand_id = request.POST.get('brand_id', settings.KODO_DEFAULT_BRAND_ID)
    model_id = request.POST.get('model_id', '')
    sn = request.POST.get('sn', '')

    if brand_id != settings.KODO_DEFAULT_BRAND_ID:
        return response(ProductBrandStatusCode.BRAND_NOT_MATCH)

    try:
        log = ConsumeInfoSubmitLogInfo.objects.get(brand_id=brand_id, model_id=model_id, serialNo=sn)
    except ConsumeModelSaleStatisticInfo.DoesNotExist:
        return response(ProductMachineStatusCode.SN_NOT_FOUND)

    return response(200, 'Query SN Success', u'查询序列号成功', data=log.data)


@logit
@transaction.atomic
def usecoupon(request):
    brand_id = request.POST.get('brand_id', settings.KODO_DEFAULT_BRAND_ID)
    model_id = request.POST.get('model_id', '')
    sn = request.POST.get('sn', '')

    if brand_id != settings.KODO_DEFAULT_BRAND_ID:
        return response(ProductBrandStatusCode.BRAND_NOT_MATCH)

    try:
        log = ConsumeInfoSubmitLogInfo.objects.get(brand_id=brand_id, model_id=model_id, serialNo=sn)
    except ConsumeModelSaleStatisticInfo.DoesNotExist:
        return response(ProductMachineStatusCode.SN_NOT_FOUND)

    log.has_used = True
    log.save()

    return response(200, 'Use Coupon Success', u'核销优惠券成功')
